==> crypt-core-4.12.0-sources.jar: de/alpharogroup/crypto/io/CryptoCipherOutputStream.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.crypto.io;

import java.io.OutputStream;

import javax.crypto.Cipher;
import javax.crypto.CipherOutputStream;


/**
 * The class {@link CryptoCipherOutputStream}.
 */
public class CryptoCipherOutputStream extends CipherOutputStream
{

	/**
	 * Instantiates a new {@link CryptoCipherOutputStream}.
	 *
	 * @param is the is
	 * @param c the c
	 */
	public CryptoCipherOutputStream(final OutputStream is, final Cipher c)
	{
		super(is, c);
	}

	/**
	 * Instantiates a new {@link CryptoCipherOutputStream}.
	 *
	 * @param is the is
	 */
	public CryptoCipherOutputStream(final OutputStream is)
	{
		super(is);
	}

}

==> crypt-core-4.17.0-sources.jar: de/alpharogroup/crypto/io/CryptoCipherOutputStream.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.crypto.io;

import java.io.OutputStream;

import javax.crypto.Cipher;
import javax.crypto.CipherOutputStream;

/**
 * The class {@link CryptoCipherOutputStream} extends the {@link CipherOutputStream}.
 */
public class CryptoCipherOutputStream extends CipherOutputStream
{

	/**
	 * Instantiates a new {@link CryptoCipherOutputStream}.
	 *
	 * @param outputStream
	 *            the output stream
	 * @param cipher
	 *            the cipher
	 */
	public CryptoCipherOutputStream(final OutputStream outputStream, final Cipher cipher)
	{
		super(outputStream, cipher);
	}

	/**
	 * Instantiates a new {@link CryptoCipherOutputStream}.
	 *
	 * @param outputStream
	 *            the output stream
	 */
	public CryptoCipherOutputStream(final OutputStream outputStream)
	{
		super(outputStream);
	}

}
